# This file was auto-generated by Fern from our API Definition.

from ..core.pydantic_utilities import UniversalBaseModel
import typing
from .filter import Filter
import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2


class FilterGroup(UniversalBaseModel):
    id: typing.Optional[int] = None
    filters: typing.List[Filter]
    conjunction: str = pydantic.Field()
    """
    Type of conjunction
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
